#
# spec file for package python-pyzstd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyzstd
Version:        0.17.0
Release:        1.1
Summary:        Python bindings to Zstandard (zstd) compression library
License:        BSD-3-Clause
URL:            https://github.com/Rogdham/pyzstd
Source:         https://files.pythonhosted.org/packages/source/p/pyzstd/pyzstd-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions >= 4.13.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libzstd-devel >= 1.4.0
BuildRequires:  python-rpm-macros
Requires:       (python-typing_extensions >= 4.13.2 if python-base < 3.13)
%python_subpackages

%description
Pyzstd module provides classes and functions for compressing and decompressing data,
using Facebook's Zstandard (or zstd as short name) algorithm.

The API is similar to Python's bz2/lzma/zlib modules.

%prep
%setup -q -n pyzstd-%{version}
# make sure we link dynamically, cannot use command line argument to pip wheel
# gh#animalize/pyzstd#18
rm -r zstd
sed -i "s/has_option('--dynamic-link-zstd')/True/" setup.py

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pyunittest_arch discover -v tests

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/pyzstd
%{python_sitearch}/pyzstd-%{version}.dist-info

%changelog
* Tue May 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.17.0
  * Upgrade zstd source code from v1.5.6 to v1.5.7
  * Raise an exception when attempting to decompress empty data
  * Add `ZstdFile.name` property
  * Deprecate `(de)compress_stream` functions
  * Use a leading `_` for private objects
  * Build wheels for Windows ARM64
  * Support for PyPy 3.11
- Update BuildRequires and Requires from setup.py
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.16.2:
  * Build wheels for Python 3.13
  * Deprecate support for Python version before 3.9 and stop
    building wheels for them
  * Compatibility with Python 3.13
  * Upgrade zstd source code from v1.5.5 to v1.5.6
  * Fix pyzstd_pep517 parameter name in
    `get_requires_for_build_wheel`
  * Deprecate support for Python version before 3.8 and stop
    building wheels for them
  * Minor fixes in type hints
  * Refactor README & CHANGELOG files
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.15.10:
  * SeekableZstdFile: fix exception when using append mode
  * SeekableZstdFile: raise TypeError when
  * SeekableZstdFile: refactor loading seek table in append mode
* Thu Jul 20 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 0.15.9
  - ZstdFile class related changes:
  * Add SeekableZstdFile class, it's a subclass of ZstdFile, supports
    Zstandard Seekable Format.
  * Add mode argument to ZstdFile.flush() method, now it can flush
    a zstd frame.
  * Add read_size and write_size arguments to ZstdFile.__init__()
    method, can work with Network File Systems better.
  * Optimize ZstdFile performance to C language level.
- Changes from 0.15.7
  - ZstdDict class changes:
  * Fix these advanced compression parameters may be ignored when
    loading a dictionary: windowLog, hashLog, chainLog, searchLog,
    minMatch, targetLength, strategy, enableLongDistanceMatching,
    ldmHashLog, ldmMinMatch, ldmBucketSizeLog, ldmHashRateLog,
    and some non-public parameters.
  * When compressing, load undigested dictionary instead of digested
    dictionary by default. Loading again an undigested is slower, see
    differences.
  * Add .as_prefix attribute. Can use zstd as a patching engine.
* Tue Jun 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Apr  7 2023 ecsos <ecsos@opensuse.org>
- Update to 0.15.6
  - Update bundled zstd source code from v1.5.4 to v1.5.5.
- Changes from 0.15.5
  - Update bundled zstd source code from v1.5.4 to v1.5.5.
- Changes from 0.15.4
  - Update bundled zstd source code from v1.5.2 to v1.5.4. v1.5.3
    is a non-public release.
  - Support pyproject.toml build mechanism (PEP-517).
    Note that specifying build options in old way may be invalid,
    see doc.
  - Support "multi-phase initialization" (PEP-489) on CPython 3.11+,
    can work with CPython sub-interpreters in the future.
    Currently this build option is disabled by default.
  - Add a command line interface (CLI).
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.15.3
- Required by py7zr
